#[repr(i32)]pub enum CreateMode {
Unspecified = 0,
AppendIfExists = 1,
ReplaceIfExists = 2,
IgnoreIfExists = 3,
ErrorIfExists = 4,
}Variants
Unspecified = 0
AppendIfExists = 1
Append the data to the table if it already exists
ReplaceIfExists = 2
Replace the table if it already exists (“OR REPLACE”)
IgnoreIfExists = 3
Ignore the request if the table already exists (“IF NOT EXISTS”)
ErrorIfExists = 4
Throw an error if the table already exists (default behavior)
Implementations
Sourceimpl CreateMode
impl CreateMode
Sourceimpl CreateMode
impl CreateMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<CreateMode>
pub fn from_str_name(value: &str) -> Option<CreateMode>
Creates an enum from field names used in the ProtoBuf definition.